@@ -16,10 +16,10 @@ import (
 	"github.com/spf13/cobra"
 	"golang.org/x/sys/unix"
 
-	"github.com/lxc/distrobuilder/generators"
-	"github.com/lxc/distrobuilder/image"
-	"github.com/lxc/distrobuilder/managers"
-	"github.com/lxc/distrobuilder/shared"
+	"github.com/lxc/distrobuilder/v3/generators"
+	"github.com/lxc/distrobuilder/v3/image"
+	"github.com/lxc/distrobuilder/v3/managers"
+	"github.com/lxc/distrobuilder/v3/shared"
 )
 
 type cmdIncus struct {
@@ -265,11 +265,35 @@ func (c *cmdIncus) run(cmd *cobra.Command, args []string, overlayDir string) err
 		imageTargets |= shared.ImageTargetContainer
 	}
 
-	for _, file := range c.global.definition.Files {
+	// Maps symbolic user/group names to their numeric IDs using information from passwd and group files.
+	userMap, groupMap, err := parsePasswdAndGroupFiles(overlayDir)
+	if err != nil {
+		c.global.logger.WithField("overlay", overlayDir).Warn("Could not parse passwd/group file: %w", err)
+	}
+
+	for i, file := range c.global.definition.Files {
 		if !shared.ApplyFilter(&file, c.global.definition.Image.Release, c.global.definition.Image.ArchitectureMapped, c.global.definition.Image.Variant, c.global.definition.Targets.Type, imageTargets) {
 			continue
 		}
 
+		if file.UID != "" && !isNumeric(file.UID) {
+			uid, exists := userMap[file.UID]
+			if exists {
+				c.global.definition.Files[i].UID = uid
+			} else {
+				c.global.logger.WithField("generator", file.Generator).Warnf("Could not find UID for user %q", file.UID)
+			}
+		}
+
+		if file.UID != "" && !isNumeric(file.GID) {
+			gid, exists := groupMap[file.GID]
+			if exists {
+				c.global.definition.Files[i].GID = gid
+			} else {
+				c.global.logger.WithField("generator", file.Generator).Warnf("Could not find GID for group %q", file.GID)
+			}
+		}
+
 		generator, err := generators.Load(file.Generator, c.global.logger, c.global.flagCacheDir, overlayDir, file, *c.global.definition)
 		if err != nil {
 			return fmt.Errorf("Failed to load generator %q: %w", file.Generator, err)
@@ -291,7 +315,7 @@ func (c *cmdIncus) run(cmd *cobra.Command, args []string, overlayDir string) err
 	if c.flagVM {
 		vmDir = filepath.Join(c.global.flagCacheDir, "vm")
 
-		err := os.Mkdir(vmDir, 0755)
+		err := os.Mkdir(vmDir, 0o755)
 		if err != nil {
 			return fmt.Errorf("Failed to create directory %q: %w", vmDir, err)
 		}
@@ -334,7 +358,7 @@ func (c *cmdIncus) run(cmd *cobra.Command, args []string, overlayDir string) err
 
 		err = vm.mountRootPartition()
 		if err != nil {
-			return fmt.Errorf("failed to mount root partion: %w", err)
+			return fmt.Errorf("failed to mount root partition: %w", err)
 		}
 
 		defer func() {
