@@ -3,7 +3,7 @@ package managers
 import (
 	"errors"
 
-	"github.com/lxc/distrobuilder/shared"
+	"github.com/lxc/distrobuilder/v3/shared"
 )
 
 type equo struct {
