@@ -7,7 +7,7 @@ import (
 	"runtime"
 	"slices"
 
-	"github.com/lxc/distrobuilder/shared"
+	"github.com/lxc/distrobuilder/v3/shared"
 )
 
 type pacman struct {
