@@ -10,7 +10,7 @@ import (
 
 	incus "github.com/lxc/incus/v6/shared/util"
 
-	"github.com/lxc/distrobuilder/shared"
+	"github.com/lxc/distrobuilder/v3/shared"
 )
 
 type yum struct {
