@@ -7,17 +7,24 @@ import (
 	"io"
 	"os"
 	"os/exec"
+	"path/filepath"
 	"regexp"
+	"slices"
 	"strconv"
 	"strings"
 	"time"
 
-	"github.com/lxc/incus/shared/util"
+	"github.com/flosch/pongo2/v4"
 	"golang.org/x/sys/unix"
-	"gopkg.in/flosch/pongo2.v3"
 	yaml "gopkg.in/yaml.v2"
 )
 
+const (
+	ContextKeyEnviron = ContextKey("environ")
+	ContextKeyStderr  = ContextKey("stderr")
+	EnvRootUUID       = "DISTROBUILDER_ROOT_UUID"
+)
+
 // EnvVariable represents a environment variable.
 type EnvVariable struct {
 	Value string
@@ -27,6 +34,68 @@ type EnvVariable struct {
 // Environment represents a set of environment variables.
 type Environment map[string]EnvVariable
 
+// ContextKey type.
+type ContextKey string
+
+// WriteFunc type.
+type WriteFunc func([]byte) (int, error)
+
+// Write implements io.Writer interface.
+func (w WriteFunc) Write(b []byte) (int, error) {
+	return w(b)
+}
+
+// CaseInsensitive returns case insensive pattern used by filepath.Glob or filepath.Match.
+func CaseInsensitive(s string) (pattern string) {
+	s1 := strings.ToLower(s)
+	s2 := strings.ToUpper(s)
+	for i := range s {
+		a := s1[i : i+1]
+		b := s2[i : i+1]
+		if a != b {
+			pattern += "[" + a + b + "]"
+		} else if strings.Contains("?*[]/", a) {
+			pattern += a
+		} else {
+			pattern += "\\" + a
+		}
+	}
+
+	return pattern
+}
+
+// FindFirstMatch find the first matched file case insensitive.
+func FindFirstMatch(dir string, elem ...string) (found string, err error) {
+	matches, err := FindAllMatches(dir, elem...)
+	if err != nil {
+		return found, err
+	}
+
+	found = matches[0]
+	return found, err
+}
+
+// FindAllMatches find all the matched files case insensitive.
+func FindAllMatches(dir string, elem ...string) (matches []string, err error) {
+	names := []string{dir}
+	for _, name := range elem {
+		names = append(names, CaseInsensitive(name))
+	}
+
+	pattern := filepath.Join(names...)
+	matches, err = filepath.Glob(pattern)
+	if err != nil {
+		return matches, err
+	}
+
+	if len(matches) == 0 {
+		err = fmt.Errorf("No match found %s", pattern)
+		return matches, err
+	}
+
+	return matches, err
+}
+
 // Copy copies a file.
 func Copy(src, dest string) error {
 	var err error
@@ -56,6 +125,10 @@ func Copy(src, dest string) error {
 // RunCommand runs a command. Stdout is written to the given io.Writer. If nil, it's written to the real stdout. Stderr is always written to the real stderr.
 func RunCommand(ctx context.Context, stdin io.Reader, stdout io.Writer, name string, arg ...string) error {
 	cmd := exec.CommandContext(ctx, name, arg...)
+	env, ok := ctx.Value(ContextKeyEnviron).([]string)
+	if ok && len(env) > 0 {
+		cmd.Env = append(os.Environ(), env...)
+	}
 
 	if stdin != nil {
 		cmd.Stdin = stdin
@@ -67,7 +140,12 @@ func RunCommand(ctx context.Context, stdin io.Reader, stdout io.Writer, name str
 		cmd.Stdout = os.Stdout
 	}
 
-	cmd.Stderr = os.Stderr
+	stderr, ok := ctx.Value(ContextKeyStderr).(io.Writer)
+	if ok && stderr != nil {
+		cmd.Stderr = stderr
+	} else {
+		cmd.Stderr = os.Stderr
+	}
 
 	return cmd.Run()
 }
@@ -135,7 +213,7 @@ func compressTarball(ctx context.Context, filename, compression string) (string,
 	}
 
 	// If supported, use as many threads as possible.
-	if util.ValueInSlice(compression, []string{"zstd", "xz", "lzma"}) {
+	if slices.Contains([]string{"zstd", "xz", "lzma"}, compression) {
 		args = append(args, "--threads=0")
 	}
 
@@ -287,7 +365,7 @@ func Retry(f func() error, attempts uint) error {
 	for i := uint(0); i < attempts; i++ {
 		err = f()
 		// Stop retrying if the call succeeded or if the context has been cancelled.
-		if err == nil || err != nil && errors.Is(err, context.Canceled) {
+		if err == nil || errors.Is(err, context.Canceled) {
 			break
 		}
 
@@ -385,7 +463,7 @@ func ParseSquashfsCompression(compression string) (string, *int, error) {
 		compression = "lzo"
 	}
 
-	if util.ValueInSlice(compression, []string{"gzip", "lzo", "lz4", "xz", "zstd", "lzma"}) {
+	if slices.Contains([]string{"gzip", "lzo", "lz4", "xz", "zstd", "lzma"}, compression) {
 		return compression, nil, nil
 	}
 
