@@ -18,7 +18,7 @@ import (
 	incus "github.com/lxc/incus/v6/shared/util"
 	"github.com/sirupsen/logrus"
 
-	"github.com/lxc/distrobuilder/shared"
+	"github.com/lxc/distrobuilder/v3/shared"
 )
 
 type common struct {
