@@ -16,7 +16,7 @@ import (
 
 	"github.com/antchfx/htmlquery"
 
-	"github.com/lxc/distrobuilder/shared"
+	"github.com/lxc/distrobuilder/v3/shared"
 )
 
 type opensuse struct {
